<?php
class EvAdBanner_Admin_Init {
    private static $prefisso_file = 'borsino-service-val-';
    private static $prefisso_slug = 'evadban-adm-';
    private static $nomi_pagine   = array(
        'home'     => 'evadban-adm-home',
        'add'      => 'evadban-adm-add',
        'settings' => 'evadban-adm-settings',
        'problems' => 'evadban-adm-problems'
    );
    private static $hook_pagine_menu;
    private static $classe_home;
    private static $classe_add;
    private static $classe_settings;
    private static $classe_problems;


    final public function __construct($aggiorna_stato = NULL) {
        spl_autoload_register(array($this, 'autoCaricamentoClassi'));

        if (is_admin()) {
            if (!has_action('admin_init', array($this, 'banner_translator'))) {
                add_action('admin_init', array($this, 'banner_translator'));
            }

            if (!has_action('admin_menu', array($this, EVADBANNER_PREFISSO . 'adm_load_menu'))) {
                add_action('admin_menu', array($this, EVADBANNER_PREFISSO . 'adm_load_menu'));
            }
        }

        if (!isset(self::$classe_home)) {
            self::$classe_home = new EvAdBanner_Home();
        }
        if (!isset(self::$classe_add)) {
            self::$classe_add = new EvAdBanner_Add();
        }
        if (!isset(self::$classe_settings)) {
            self::$classe_settings = new EvAdBanner_Settings();
        }
        if (!isset(self::$classe_problems)) {
            self::$classe_problems = new EvAdBanner_Problems();
        }

        $this->data_attuale = date ('Y-m-d H:i:s');
    }

    final static public function attivazione_plugin() {
        // Aggiungo le impostazioni del plugin a WP
        $data_attuale = date ('Y-m-d H:i:s');
        global $wpdb;
        if (!get_option(EVADBANNER_PREFISSO."plugin_attivo")) {
            update_option(EVADBANNER_PREFISSO."plugin_attivo", true);
            update_option(EVADBANNER_PREFISSO."data_attivazione", $data_attuale);
        }
        if (!get_option(EVADBANNER_PREFISSO."data_installazione")) {
            add_option(EVADBANNER_PREFISSO."versione", EVADBANNER_VERSION);
            add_option(EVADBANNER_PREFISSO."data_installazione", $data_attuale);
//            add_option(EVADBANNER_PREFISSO.'impostazioni', parent::$impostazioni_iniziali, '', 'no');
        }
    }
    final static public function disattivazione_plugin () {
        global $wpdb;
        if (update_option(EVADBANNER_PREFISSO."plugin_attivo", false)){
            // ins. mess. per debug
        }
    }
    final static public function getPrefissoXMetodiEForm () {
        return self::$prefisso_file;
    }

    final public function banner_translator () {
//        load_plugin_textdomain(EVADBANNER_ANCORA_TRAD, false, EVADBANNER_PLUGIN_DIR.'/languages' );
        load_plugin_textdomain( EVADBANNER_ANCORA_TRAD, false, EVADBANNER_ANCORA_TRAD.'/languages' );
    }

    final static public function getPagesName($nome_pagina = null) {
        if (isset($nome_pagina)) {
            if (isset(self::$nomi_pagine[$nome_pagina])) {
                return self::$nomi_pagine[$nome_pagina];
            } else {
                return false;
            }
        }
        return self::$nomi_pagine;
    }



    final public function fmt_evadban_adm_load_menu () {
        self::carica_menu_exec();
    }
    private function carica_menu_exec () {
        self::$hook_pagine_menu['home'] = add_menu_page(
            'Events/ADS Banner',                                    // titolo scheda
            'Events/ADS Banner',                                    // titolo menu (e prima voce link)
            'administrator',                                        // permessi per poterlo vedere
            self::$nomi_pagine['home'],                             // ancora tra il link e la pagina (o anche nome interno della pagina)
            array(self::$classe_home, 'visualizza_pagina_home')     // funzione con la pagina
        );
        self::$hook_pagine_menu['add'] = add_submenu_page(
            self::$prefisso_slug.'home',
            __("Create New Banner", EVADBANNER_ANCORA_TRAD),
            __("Add Banner", EVADBANNER_ANCORA_TRAD),
            'administrator',
            self::$nomi_pagine['add'],
            array(self::$classe_add, "visualizza_pagina_add")
        );
        self::$hook_pagine_menu['settings'] = add_submenu_page(
            self::$prefisso_slug.'home',
            __("Set the Banner", EVADBANNER_ANCORA_TRAD),
            __("Banner Settings", EVADBANNER_ANCORA_TRAD),
            'administrator',
            self::$nomi_pagine['settings'],
            array(self::$classe_settings, 'visualizza_pagina_settings')
        );
        self::$hook_pagine_menu['problems'] = add_submenu_page(
            self::$prefisso_slug.'home',
            __("Issues partial solved", EVADBANNER_ANCORA_TRAD),
            __("Banner Issues", EVADBANNER_ANCORA_TRAD),
            'administrator',
            self::$nomi_pagine['problems'],
            array(self::$classe_problems, 'visualizza_pagina_problems')
        );
    }


    final public function autoCaricamentoClassi ($classe) {
        if (strpos($classe, 'EvAdBanner_') === false) {
            return;
        }

        $classe = str_replace('EvAdBanner_', '', $classe);
        if ('Banner' === $classe) {
            $dir = '';
        } else {
            $dir = 'admin/';
        }

        include_once EVADBANNER_PLUGIN_DIR.$dir.strtolower($classe).'_class.php';
    }
}